@@ -12,7 +12,7 @@ MINILIB_SOURCES = "colourscheme.c dlg.c display.c dragrcv.c dynopts.c " \
         "encodings.c globalopts.c logo.c options.c optsfile.c rtdbus.c"
 
 ROXTERM_CONFIG_SOURCES = "capplet.c colourgui.c configlet.c getname.c " \
-        "optsdbus.c profilegui.c"
+        "optsdbus.c profilegui.c shortcuts.c"
 
 ROXTERM_SOURCES = "about.c main.c multitab.c multitab-close-button.c " \
         "multitab-label.c menutree.c optsdbus.c roxterm.c shortcuts.c " \
@@ -38,20 +38,14 @@ if ctx.mode == 'configure' or ctx.mode == 'help':
     ctx.arg_disable('sm', "Don't enable session management")
     ctx.arg_disable('gtk3', "Use GTK+2 instead of GTK+3 and compatible "
             "version of VTE", default = None)
-    ctx.arg_disable('gettext', "Disable translation of program strings with " \
-            "gettext", default = None)
-    ctx.arg_disable('po4a', "Disable translation of documentation with po4a",
-            default = None)
-    ctx.arg_disable('translations', "Disable all translations", default = None)
-    ctx.arg_disable('nls', "Disable all translations (same as --disable-nls)",
+    ctx.arg_disable('nls', "Disable all translations",
             default = None)
+    ctx.arg_disable('translations',
+            "Disable all translations (same as --disable-nls)", default = None)
     ctx.arg_disable('git', "Assume this is a release tarball: "
             "don't attempt to generate changelogs, pixmaps etc")
     ctx.arg_enable("rox-locales",
             "Make symlinks so ROX app can load translations")
-    ctx.arg_enable("deprecated-bg-opts", "Enables background options such as " \
-            "transparency even if deprecated by VTE. May cause compiler " \
-            "warnings and, in the future, compiler or link errors.")
 
 if ctx.mode == 'configure':
 
@@ -126,34 +120,32 @@ if ctx.mode == 'configure':
 
     ctx.setenv('BUG_TRACKER', "http://sourceforge.net/tracker/?group_id=124080")
 
-    gt = ctx.env['ENABLE_GETTEXT']
-    po4a = ctx.env['ENABLE_PO4A']
     trans = ctx.env['ENABLE_TRANSLATIONS'] and ctx.env['ENABLE_NLS']
-    if trans != False and gt != False:
+    if trans != False:
         try:
             ctx.find_prog_env("xgettext")
             ctx.find_prog_env("msgcat")
             ctx.find_prog_env("msgmerge")
             ctx.find_prog_env("msgfmt")
         except MaitchNotFoundError:
-            if trans == True or gt == True:
+            if trans == True:
                 raise
             else:
-                mprint("WARNING: gettext tools not found, not building " \
-                        "programs' translations", file = sys.stderr)
+                mprint("WARNING: Translation tools not found, not building " \
+                        " programs' translations", file = sys.stderr)
                 ctx.setenv('HAVE_GETTEXT', False)
         else:
             ctx.setenv('HAVE_GETTEXT', True)
     else:
         ctx.setenv('HAVE_GETTEXT', False)
 
-    if trans != False and po4a != False:
+    if trans != False:
         try:
             ctx.find_prog_env("po4a-gettextize")
             ctx.find_prog_env("po4a-updatepo")
             ctx.find_prog_env("po4a-translate")
         except MaitchNotFoundError:
-            if trans == True or po4a == True:
+            if trans == True:
                 raise
             else:
                     mprint("WARNING: po4a tools not found, not building " \
@@ -166,10 +158,29 @@ if ctx.mode == 'configure':
                     "--package-version=${VERSION} " \
                     "--copyright-holder='Tony Houghton' " \
                     "--msgid-bugs-address=${BUG_TRACKER}")
-            ctx.setenv('PO4ADIR', "${TOP_DIR}/po4a")
+            ctx.setenv('PO4ADIR', "${ABS_TOP_DIR}/po4a")
+            ctx.setenv('PO4ABUILDDIR', "${ABS_BUILD_DIR}/po4a")
     else:
         ctx.setenv('HAVE_PO4A', False)
 
+    if trans != False and ctx.env['HAVE_GETTEXT']:
+        try:
+            ctx.find_prog_env("itstool")
+        except MaitchNotFoundError:
+            if trans == True:
+                raise
+            else:
+                    mprint("WARNING: itstool not found, not building " \
+                            "AppData file's translations", file = sys.stderr)
+                    ctx.setenv('HAVE_ITSTOOL', False)
+        else:
+            ctx.setenv('HAVE_ITSTOOL', True)
+            ctx.setenv('POXML_DIR', "${ABS_TOP_DIR}/poxml")
+            ctx.setenv('POXML_BUILD_DIR', "${ABS_BUILD_DIR}/poxml")
+            ctx.setenv('APPDATA_ITS', "${POXML_DIR}/appdata.its")
+    else:
+        ctx.setenv('HAVE_ITSTOOL', False)
+
     gda = ctx.env.get("WITH_GNOME_DEFAULT_APPLICATIONS")
     if gda == None or gda == True:
         try:
@@ -190,9 +201,7 @@ if ctx.mode == 'configure':
             ctx.pkg_config('gtk+-3.0', 'GTK')
             ctx.pkg_config('vte-2.90', 'VTE')
             vte_version = ctx.prog_output("${PKG_CONFIG} --modversion vte-2.90")
-            ctx.setenv('VTE_BACKGROUND_DEPRECATED',
-                    vte_version >= "0.34.8" and not \
-                    ctx.env['ENABLE_DEPRECATED_BG_OPTS'])
+            ctx.setenv('NEED_TRANSPARENCY_FIX', vte_version >= "0.34.8")
         except MaitchChildError:
             if gtk3 == True:
                 raise
@@ -202,7 +211,7 @@ if ctx.mode == 'configure':
     if not gtk3:
         ctx.pkg_config('gtk+-2.0', 'GTK', '2.18')
         ctx.pkg_config('vte', 'VTE', '0.20')
-        ctx.setenv('VTE_BACKGROUND_DEPRECATED', 0)
+        ctx.setenv('NEED_TRANSPARENCY_FIX', 0)
 
     sm = ctx.env['ENABLE_SM']
     if sm != False:
@@ -223,7 +232,8 @@ if ctx.mode == 'configure':
     for f in "get_current_dir_name g_mkdir_with_parents " \
             "gdk_window_get_display gdk_window_get_screen " \
             "gtk_widget_get_realized gtk_widget_get_mapped " \
-            "gtk_combo_box_text_new gtk_rc_style_unref".split():
+            "gtk_combo_box_text_new gtk_rc_style_unref " \
+            "gtk_drag_begin_with_coordinates".split():
         ctx.check_func(f, "${CFLAGS} ${MCFLAGS} ${GTK_CFLAGS}",
                 "${LIBS} ${GTK_LIBS}")
     for f in ["vte_terminal_search_set_gregex", "vte_terminal_get_pty_object"]:
@@ -261,16 +271,17 @@ if ctx.mode == 'configure':
         ctx.define('ENABLE_NLS', None)
     ctx.define_from_var('LOCALEDIR')
 
-    ctx.define_from_var('VTE_BACKGROUND_DEPRECATED')
+    ctx.define_from_var('NEED_TRANSPARENCY_FIX')
 
     ctx.subst_file("${TOP_DIR}/roxterm.1.xml.in",
-            "${TOP_DIR}/roxterm.1.xml", True)
+            "${BUILD_DIR}/roxterm.1.xml", True)
     ctx.subst_file("${TOP_DIR}/roxterm-config.1.xml.in",
-            "${TOP_DIR}/roxterm-config.1.xml", True)
-    ctx.subst_file("${TOP_DIR}/roxterm.spec.in", "${TOP_DIR}/roxterm.spec")
+            "${BUILD_DIR}/roxterm-config.1.xml", True)
+    ctx.subst_file("${TOP_DIR}/roxterm.spec.in", "${BUILD_DIR}/roxterm.spec")
     ctx.setenv('APPINFO_STRING', "${VERSION} (%s)" % \
             time.strftime("%Y-%m-%d", time.gmtime(time.time())))
-    ctx.subst_file(APPINFO + ".in", APPINFO)
+    if not os.path.exists(ctx.subst(APPINFO)):
+        ctx.subst_file(APPINFO + ".in", APPINFO)
     ctx.save_if_different("version.h",
             '/* Auto-generated by mscript.py */\n' \
             '#ifndef VERSION_H\n' \
@@ -369,7 +380,7 @@ elif ctx.mode == 'build':
         xmltomanrule = "${XMLTOMAN} ${XMLTOMAN_OPTS} ${SRC} ${XMLTOMAN_OUTPUT}"
         # Something is causing a thread to hang between calling xsltproc
         # and exiting from subprocess.Popen. Could it be trying to run two
-        # at once. Making one wdep on the other should stop jobs overlapping.
+        # at once? Making one wdep on the other should stop jobs overlapping.
         ctx.add_rule(Rule(
                 rule = xmltomanrule,
                 targets = "roxterm.1",
@@ -396,6 +407,8 @@ elif ctx.mode == 'build':
         fp = open(sources[0], 'r')
         s = fp.read()
         fp.close()
+        s = re.sub(r'requires lib="gtk\+" version=".*"',
+                r'requires lib="gtk+" version="2.18"', s)
         s = re.sub(r'class="GtkBox" id=(.*)hbox',
                 r'class="GtkHBox" id=\1hbox', s)
         s = re.sub(r'class="GtkBox" id=(.*)vbox',
@@ -404,20 +417,20 @@ elif ctx.mode == 'build':
         fp = open(targets[0], 'w')
         fp.close()
     ctx.add_rule(Rule(rule = process_ui,
-            sources = "${SRC_DIR}/roxterm-config.ui",
-            targets = "roxterm-config.ui-stamp"))
+            sources = "${ABS_SRC_DIR}/roxterm-config.ui",
+            targets = "${ABS_BUILD_DIR}/roxterm-config.ui-stamp"))
 
     # Translations (gettext)
     if ctx.env['HAVE_GETTEXT']:
-        podir = '${BUILD_DIR}/po'
+        podir = '${ABS_BUILD_DIR}/po'
         ctx.add_rule(Rule(rule = mkdir_rule, targets = podir))
         args = { 'copyright_holder': "(c) 2013 Tony Houghton",
                 'version': "${VERSION}",
                 'bugs_addr': "${BUG_TRACKER}",
-                'diffpat': '^"Project-Id-Version:',
-                'use_shell': True }
-        code_pot = '${BUILD_DIR}/po/code.pot'
-        glade_pot = '${BUILD_DIR}/po/glade.pot'
+                'use_shell': True,
+                'dir': podir }
+        code_pot = '${ABS_BUILD_DIR}/po/code.pot'
+        glade_pot = '${ABS_BUILD_DIR}/po/glade.pot'
         trans_rules = PoRulesFromLinguas(ctx, **args) + \
                 PotRules(ctx,
                         targets = code_pot,
@@ -427,21 +440,23 @@ elif ctx.mode == 'build':
         for r in trans_rules:
             ctx.add_rule(r)
         ctx.add_rule(PotRule(ctx,
-                sources = '${SRC_DIR}/roxterm-config.ui',
+                sources = '../src/roxterm-config.ui',
                 targets = glade_pot,
                 deps = podir,
                 xgettext_opts = '-L Glade',
-                wdeps = "roxterm-config.ui-stamp"))
+                wdeps = "${ABS_BUILD_DIR}/roxterm-config.ui-stamp",
+                dir = "${ABS_TOP_DIR}/po"))
         ctx.add_rule(Rule(sources = [code_pot, glade_pot],
-                targets = '${TOP_DIR}/po/${PACKAGE}.pot',
-                rule = '${MSGCAT} -o ${TGT} ${SRC}'))
+                targets = '${ABS_TOP_DIR}/po/${PACKAGE}.pot',
+                rule = '${MSGCAT} -o ${TGT} ${SRC}',
+                diffpat = gettext_diffpat))
 
     # Symlinks so ROX can use translations
     if ctx.env["ENABLE_ROX_LOCALES"]:
         def add_rox_locale(ctx, l, f):
             d = opj("locale", l, "LC_MESSAGES")
             ctx.add_rule(Rule(rule = mkdir_rule, targets = d))
-            ctx.add_rule(Rule(rule = "ln -nfs ../../../po/%s.mo ${TGT}" % l,
+            ctx.add_rule(Rule(rule = "ln -nfs ../../po/%s.mo ${TGT}" % l,
                     targets = opj(d, "roxterm.mo"),
                     wdeps = [d, opj("po", "%s.mo" % l)]))
 
@@ -452,9 +467,9 @@ elif ctx.mode == 'build':
 
 
     # Translations (po4a)
-    linguas = parse_linguas(ctx)
-    charset_rule = "${SED} -i s/charset=CHARSET/charset=UTF-8/ ${TGT}"
     if ctx.env['HAVE_PO4A']:
+        linguas = parse_linguas(ctx, podir = "${PO4ADIR}")
+        charset_rule = "${SED} -i s/charset=CHARSET/charset=UTF-8/ ${TGT}"
         ctx.ensure_out_dir("po4a")
         if ctx.env['XMLTOMAN']:
             # Workaround for deadlock (?)
@@ -463,65 +478,70 @@ elif ctx.mode == 'build':
                 ctx.add_rule(Rule(rule = ["${PO4A_GETTEXTIZE} ${PO4AOPTS} " \
                         "-f docbook -m ${SRC} -p ${TGT}",
                         charset_rule],
-                        sources = "${TOP_DIR}/%s.1.xml.in" % m,
-                        targets = "${PO4ADIR}/%s.1.pot" % m,
+                        sources = "../%s.1.xml.in" % m,
+                        targets = "%s.1.pot" % m,
                         where = NOWHERE,
-                        diffpat = ['^"Project-Id-Version:',
-                                '^"POT-Creation-Date:'],
+                        diffpat = gettext_diffpat,
+                        dir = "${PO4ADIR}",
                         use_shell = True))
                 for l in linguas:
                     po = "${PO4ADIR}/%s.1.%s.po" % (m, l)
                     ctx.add_rule(Rule(rule = ["${PO4A_UPDATEPO} ${PO4AOPTS} " \
                             "-f docbook -m ${SRC} -p ${TGT}",
-                            charset_rule],
-                            sources = ["${TOP_DIR}/%s.1.xml.in" % m,
-                                    "${PO4ADIR}/%s.1.pot" % m],
+                            charset_rule,
+                            "rm -f ${TGT}~"],
+                            sources = ["../%s.1.xml.in" % m, "%s.1.pot" % m],
                             targets = po,
-                            diffpat = '^"POT-Creation-Date:',
+                            diffpat = gettext_diffpat,
                             where = NOWHERE,
+                            dir = "${PO4ADIR}",
                             use_shell = True))
                     ctx.add_rule(Rule(rule = "${PO4A_TRANSLATE} "
                             "${PO4ACHARSET} " \
-                            "-k 0 -f docbook -m ${TOP_DIR}/%s.1.xml.in " \
+                            "-k 0 -f docbook -m ../%s.1.xml.in " \
                             "-p ${SRC} -l ${TGT}" % m,
                             sources = po,
-                            targets = "po4a/%s.1.%s.xml.in" % (m, l),
+                            targets = "${ABS_BUILD_DIR}/po4a/%s.1.%s.xml.in" % \
+                                    (m, l),
                             where = NOWHERE,
+                            dir = "${PO4ADIR}",
                             use_shell = True))
                     ctx.add_rule(Rule(rule = "${SED} " \
                             "'s/@VERSION@/${VERSION}/; " \
                             "s#@htmldir@#${HTMLDIR}#' <${SRC} >${TGT}",
-                            sources = "po4a/%s.1.%s.xml.in" % (m, l),
-                            targets = "po4a/%s.1.%s.xml" % (m, l),
+                            sources = "${PO4ABUILDDIR}/%s.1.%s.xml.in" % (m, l),
+                            targets = "${PO4ABUILDDIR}/%s.1.%s.xml" % (m, l),
                             deps = po,
                             where = NOWHERE,
                             use_shell = True))
-                    mtarget = "po4a/%s/%s.1" % (l, m)
+                    mtarget = "${PO4ABUILDDIR}/%s/%s.1" % (l, m)
                     ctx.add_rule(Rule( \
                             rule = [mk_parent_dir_rule, xmltomanrule],
-                            sources = "po4a/%s.1.%s.xml" % (m, l),
+                            sources = "${PO4ABUILDDIR}/%s.1.%s.xml" % (m, l),
                             targets = mtarget,
                             wdeps = lastmtarget,
                             where = NOWHERE))
                     lastmtarget = mtarget
         for h in ROXTERM_HTML_BASENAMES:
-            master = "${TOP_DIR}/Help/en/%s.html" % h
-            pot = "${PO4ADIR}/%s.html.pot" % h
+            master = "../Help/en/%s.html" % h
+            pot = "%s.html.pot" % h
             ctx.add_rule(Rule(rule = ["${PO4A_GETTEXTIZE} ${PO4AOPTS} " \
                     "-f xhtml -m ${SRC} -p ${TGT}",
                     charset_rule,
                     "${SED} -i 's/SOME DESCRIPTIVE TITLE/" \
                             "Translations for roxterm docs/' ${TGT}",
-                    "${SED} -i 's/Copyright (C) YEAR/Copyright (C) 2010/' " \
+                    "${SED} -i 's/Copyright (C) YEAR/" + \
+                            "Copyright (C) 2010-2014/' " \
                             "${TGT}",
                     "${SED} -i 's/FIRST AUTHOR <EMAIL@ADDRESS>, YEAR/"
-                            "Tony Houghton <h@realh.co.uk>, 2010/' ${TGT}"],
+                            "Tony Houghton <h@realh.co.uk>, 2014/' ${TGT}"],
                     sources = master,
-                    targets = pot,
+                    targets = "${PO4ADIR}/" + pot,
                     where = NOWHERE,
+                    dir = "${PO4ADIR}",
                     use_shell = True))
             for l in linguas:
-                ldir = "${TOP_DIR}/Help/%s" % l
+                ldir = "../Help/%s" % l
                 ctx.ensure_out_dir(ldir)
                 po = "${PO4ADIR}/%s.html.%s.po" % (h, l)
                 ctx.add_rule(Rule(rule = ["${PO4A_UPDATEPO} ${PO4AOPTS} " \
@@ -530,6 +550,7 @@ elif ctx.mode == 'build':
                         sources = [master, pot],
                         targets = po,
                         where = NOWHERE,
+                        dir = "${PO4ADIR}",
                         use_shell = True))
                 ctx.add_rule(Rule(rule = [mk_parent_dir_rule,
                         "${PO4A_TRANSLATE} "
@@ -537,23 +558,71 @@ elif ctx.mode == 'build':
                         "-k 0 -f xhtml -m %s " \
                         "-p ${SRC} -l ${TGT}" % master],
                         sources = po,
-                        targets = "%s/%s.html" % (ldir, h),
+                        targets = "${ABS_TOP_DIR}/Help/%s/%s.html" % (ldir, h),
                         where = NOWHERE,
+                        dir = "${PO4ADIR}",
                         use_shell = True))
 
 
+    # Translations (itstool)
+    if ctx.env['HAVE_ITSTOOL']:
+        podir = "${POXML_DIR}"
+        linguas = parse_linguas(ctx, podir = podir)
+        basename = "roxterm.appdata.xml"
+        xmlout = "${ABS_BUILD_DIR}/" + basename
+        xmlin = "../" + basename + ".in"
+        potfile = "${POXML_DIR}/roxterm.appdata.xml.pot"
+        ctx.add_rule(Rule( \
+                rule = ["${ITSTOOL} -i ${APPDATA_ITS} -o ${TGT} ${SRC}",
+                    "${SED} -i 's/Project-Id-Version: PACKAGE VERSION/" \
+                        "Project-Id-Version: roxterm ${VERSION}/' " \
+                        "${TGT}"],
+                sources = xmlin,
+                targets = potfile,
+                deps = "${APPDATA_ITS}",
+                where = NOWHERE,
+                dir = podir,
+                use_shell = True))
+        if linguas:
+            for r in PoRulesFromLinguas(ctx, podir = podir,
+                    modir = "${POXML_BUILD_DIR}",
+                    sources = potfile):
+                ctx.add_rule(r)
+            sources = []
+            for l in parse_linguas(ctx, podir = podir):
+                sources.append(opj("${POXML_BUILD_DIR}", l + ".mo"))
+            ctx.add_rule(Rule( \
+                    rule = "${ITSTOOL} -i ${APPDATA_ITS} -j " + xmlin +
+                            " -o ${TGT} ${SRC}",
+                    sources = sources,
+                    targets = xmlout,
+                    dir = podir,
+                    where = NOWHERE))
+    else:
+        linguas = None
+    if not linguas:
+        ctx.add_rule(Rule(rule = "cp ${SRC} ${TGT}",
+                sources = "${ABS_TOP_DIR}/roxterm.appdata.xml.in",
+                targets = "${ABS_BUILD_DIR}/roxterm.appdata.xml",
+                where = NOWHERE))
+
+
 elif ctx.mode == "install" or ctx.mode == "uninstall":
 
     ctx.install_bin("roxterm roxterm-config")
     ctx.install_data("roxterm-config.ui")
     ctx.install_data("roxterm.desktop", "${DATADIR}/applications")
+    ctx.install_data("roxterm.appdata.xml", "${DATADIR}/appdata")
     if ctx.env['XMLTOMAN']:
         ctx.install_man("roxterm.1 roxterm-config.1")
     ctx.install_doc("AUTHORS ChangeLog README")
     ctx.install_doc(ctx.glob("*.html",
             subdir = ctx.subst("${TOP_DIR}/Help/en")),
             "${HTMLDIR}/en")
-    ctx.install_doc(ctx.glob("*",
+    ctx.install_doc(ctx.glob("*.png",
+            subdir = ctx.subst("${TOP_DIR}/Help/lib")),
+            "${HTMLDIR}/lib")
+    ctx.install_doc(ctx.glob("*.css",
             subdir = ctx.subst("${TOP_DIR}/Help/lib")),
             "${HTMLDIR}/lib")
     ctx.install_data("roxterm.svg", "${DATADIR}/icons/hicolor/scalable/apps")
@@ -594,7 +663,11 @@ elif ctx.mode == "install" or ctx.mode == "uninstall":
 
 elif ctx.mode == 'pristine' or ctx.mode == 'clean':
 
-    clean = ["${TOP_DIR}/maitch.pyc"]
+    clean = ["${TOP_DIR}/maitch.pyc"] + \
+            ctx.glob("*.po~", "${TOP_DIR}", "po") + \
+            ctx.glob("*.po~", "${TOP_DIR}", "po4a") + \
+            ctx.glob("*.po~", "${TOP_DIR}", "poxml")
+
     if ctx.mode == 'pristine':
         clean += [APPINFO, VFILE, "${TOP_DIR}/ChangeLog"] + \
             ["${TOP_DIR}/Help/" + f for f in \
@@ -603,16 +676,21 @@ elif ctx.mode == 'pristine' or ctx.mode == 'clean':
                 "favicon.ico logo_text.png roxterm_logo.png".split()] + \
             ctx.glob("*.pot", "${TOP_DIR}", "po") + \
             ctx.glob("*.pot", "${TOP_DIR}", "po4a") + \
-            ctx.glob("*.po~", "${TOP_DIR}", "po") + \
-            ctx.glob("*.po~", "${TOP_DIR}", "po4a")
-        for d in \
-                [ctx.subst("${TOP_DIR}/Help/" + d) for d in "es fr gl".split()]:
-            recursively_remove(d, False, [])
+            ctx.glob("*.pot", "${TOP_DIR}", "poxml")
+
     for f in clean:
         ctx.delete(f)
 
+    # Generated HTML doesn't go in tarball so must be cleaned
+    f = open(ctx.subst("${TOP_DIR}/po4a/LINGUAS"), 'r')
+    hd = ctx.subst("${TOP_DIR}/Help/")
+    for d in [hd + l.strip() for l in f.readlines() + ['pt']]:
+        recursively_remove(d, False, [])
+    f.close()
+
 elif ctx.mode == 'dist':
 
+    ctx.subst_file(APPINFO + ".in", APPINFO)
     ctx.add_dist("AUTHORS Help/AUTHORS " \
             "genlog ChangeLog ChangeLog.old Config " \
             "COPYING COPYING-LGPL Help/en Help/lib/header.png " \
@@ -622,6 +700,7 @@ elif ctx.mode == 'dist':
             "INSTALL INSTALL.Debian " \
             "NEWS README README.translations " \
             "roxterm.1.xml.in roxterm-config.1.xml.in " \
+            "roxterm.appdata.xml.in " \
             "roxterm.desktop roxterm.lsm.in roxterm.spec.in " \
             "roxterm.svg roxterm.xml TODO " \
             "src/roxterm-config.glade src/roxterm-config.ui")
@@ -636,16 +715,15 @@ elif ctx.mode == 'dist':
     if os.path.exists("AppInfo.xml"):
         ctx.add_dist("AppInfo.xml")
     # Translations
-    ctx.add_dist("po/LINGUAS po4a/LINGUAS")
-    files = ctx.glob("*.po", os.curdir, "po4a") + \
-            ctx.glob("*.pot", os.curdir, "po4a")
-    if files:
-        ctx.add_dist(files)
-    if os.path.exists("po/POTFILES.in"):
-        ctx.add_dist("po/POTFILES.in")
-    if os.path.exists("po/roxterm.pot"):
-        ctx.add_dist("po/roxterm.pot")
-    files = ctx.glob("*.po", os.curdir, "po", False)
+    for f in ("po/LINGUAS", "po4a/LINGUAS", "poxml/LINGUAS",
+            "po/POTFILES.in", "po/roxterm.pot",
+            "poxml/appdata.its", "poxml/roxterm.appdata.xml.pot"):
+        if os.path.exists(f):
+            ctx.add_dist(f)
+    files = ctx.glob("*.po", os.curdir, "po") + \
+            ctx.glob("*.po", os.curdir, "po4a") + \
+            ctx.glob("*.pot", os.curdir, "po4a") + \
+            ctx.glob("*.po", os.curdir, "poxml")
     if files:
         ctx.add_dist(files)
 
