@@ -28,9 +28,11 @@
 #include "optsdbus.h"
 #include "optsfile.h"
 #include "profilegui.h"
+#include "shortcuts.h"
 
 #include <ctype.h>
 #include <stdarg.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <unistd.h>
@@ -577,7 +579,6 @@ static gboolean remove_name_from_list(ConfigletList *cl, const char *old_name)
 static void configlet_copy(ConfigletList *cl,
         const char *old_leaf, const char *new_leaf)
 {
-    GError *error = NULL;
     gboolean success = FALSE;
 
     if (cl->encodings)
@@ -590,32 +591,9 @@ static void configlet_copy(ConfigletList *cl,
     {
         char *old_path = options_file_build_filename(cl->family, old_leaf,
                 NULL);
-        char *new_path = options_file_filename_for_saving(cl->family,
-            new_leaf, NULL);
-        char *dir = options_file_filename_for_saving(cl->family, NULL);
-        char *buffer = NULL;
-        gsize size;
 
-        if (!g_file_test(dir, G_FILE_TEST_IS_DIR))
-        {
-            if (g_mkdir_with_parents(dir, 0755) == -1)
-            {
-                dlg_warning(GTK_WINDOW(cl->cg->widget),
-                        _("Unable to create directory '%s'"), dir);
-                return;
-            }
-        }
-        if (g_file_test(old_path, G_FILE_TEST_IS_REGULAR))
-        {
-            if (g_file_get_contents(old_path, &buffer, &size, &error))
-                success = g_file_set_contents(new_path, buffer, size, &error);
-        }
-        else
-        {
-            success = g_file_set_contents(new_path, "", -1, &error);
-        }
-        g_free(buffer);
-        g_free(new_path);
+        success = options_file_copy_to_user_dir(GTK_WINDOW(cl->cg->widget),
+                old_path, cl->family, new_leaf);
         g_free(old_path);
     }
     if (success)
@@ -624,14 +602,6 @@ static void configlet_copy(ConfigletList *cl,
         optsdbus_send_stuff_changed_signal(OPTSDBUS_ADDED, cl->family,
                 new_leaf, NULL);
     }
-    else
-    {
-        dlg_warning(GTK_WINDOW(cl->cg->widget),
-                _("Unable to copy profile/scheme: %s"),
-                error && error->message ? error->message : _("unknown reason"));
-    }
-    if (error)
-        g_error_free(error);
 }
 
 /* This is Edit for Encodings */
@@ -705,9 +675,7 @@ static void edit_thing_by_name(ConfigletList *cl, const char *name)
     }
     else if (!strcmp(cl->family, "Shortcuts"))
     {
-        dlg_message(GTK_WINDOW(cl->cg->widget),
-                _("Shortcuts can currently only be edited by hovering "
-                    "over the menu entries and pressing keys"));
+        shortcuts_edit(GTK_WINDOW(cl->cg->widget), name);
     }
     else if (cl->encodings)
     {
@@ -798,7 +766,7 @@ static void on_copy_clicked(ConfigletList *cl)
     if (cl->encodings)
     {
         title = g_strdup_printf(_("Add Encoding"));
-        button_label = GTK_STOCK_ADD;
+        button_label = _("_Add");
         existing = encodings_list(cl->encodings);
     }
     else
@@ -807,7 +775,7 @@ static void on_copy_clicked(ConfigletList *cl)
 
         title = g_strdup_printf(_("Copy %s"),
             full_name_from_family(cl->family));
-        button_label = GTK_STOCK_COPY;
+        button_label = _("_Copy");
         existing = (char const **) dynamic_options_list(dynopts);
     }
     if (old_name || cl->encodings)
@@ -936,6 +904,12 @@ void on_shortcuts_delete_clicked(GtkButton *button, ConfigletData *cg)
     on_delete_clicked(&cg->shortcuts);
 }
 
+void on_shortcuts_edit_clicked(GtkButton *button, ConfigletData *cg)
+{
+    (void) button;
+    edit_selected_thing(&cg->shortcuts);
+}
+
 void on_encodings_delete_clicked(GtkButton *button, ConfigletData *cg)
 {
     (void) button;
@@ -965,7 +939,7 @@ void on_rename_clicked(ConfigletList *cl)
     if (old_name || cl->encodings)
     {
         char *new_name = getname_run_dialog(GTK_WINDOW(cl->cg->widget),
-                old_name, existing, title, GTK_STOCK_APPLY, NULL,
+                old_name, existing, title, _("Apply"), NULL,
                 cl->encodings == NULL);
 
         if (new_name)
@@ -1079,7 +1053,19 @@ gboolean configlet_open(GdkScreen *scrn)
         configlet_setup_family(cg, &cg->shortcuts, "Shortcuts");
         configlet_setup_family(cg, &cg->encodings, "encodings");
 
-        capplet_set_boolean_toggle(&cg->capp, "edit_shortcuts", FALSE);
+        if (gtk_is_newer_than(3, 10))
+        {
+            gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(
+                    cg->capp.builder, "edit_shortcuts")));
+            gtk_widget_show(GTK_WIDGET(gtk_builder_get_object(
+                    cg->capp.builder, "shortcuts_edit")));
+        }
+        else
+        {
+            gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(
+                    cg->capp.builder, "shortcuts_edit")));
+            capplet_set_boolean_toggle(&cg->capp, "edit_shortcuts", FALSE);
+        }
         capplet_set_radio(&cg->capp, "warn_close", 3);
         capplet_set_boolean_toggle(&cg->capp, "only_warn_running", FALSE);
         if (g_object_class_find_property(
