@@ -42,7 +42,7 @@ gboolean global_options_fullscreen = FALSE;
 gboolean global_options_maximise = FALSE;
 gboolean global_options_tab = FALSE;
 gboolean global_options_fork = FALSE;
-int global_options_workspace = -1;
+guint32 global_options_workspace = WORKSPACE_UNDEFINED;
 
 static void correct_scheme(const char *bad_name, const char *good_name)
 {
@@ -69,7 +69,7 @@ static void global_options_reset(void)
     global_options_replace = FALSE;
     global_options_fullscreen = FALSE;
     global_options_tab = FALSE;
-    global_options_workspace = -1;
+    global_options_workspace = WORKSPACE_UNDEFINED;
     global_options_disable_sm = FALSE;
     options_reload_keyfile(global_options);
     correct_schemes();
@@ -198,9 +198,9 @@ static gboolean global_options_set_tab(const gchar *option_name,
     (void) option_name;
     global_options_tab = TRUE;
     if (value)
-        global_options_workspace = atoi(value);
+        global_options_workspace = (guint32) strtoul(value, NULL, 0);
     else
-        global_options_workspace = -1;
+        global_options_workspace = WORKSPACE_UNDEFINED;
     return TRUE;
 }
 
