@@ -50,7 +50,10 @@ extern gboolean global_options_maximise;
 
 /* Whether to try to open new terminal in an existing window */
 extern gboolean global_options_tab;
-extern int global_options_workspace;
+
+extern guint32 global_options_workspace;
+#define WORKSPACE_ALL 0xffffffff
+#define WORKSPACE_UNDEFINED 0xfffffffe
 
 /* Fork first instance */
 extern gboolean global_options_fork;
