@@ -66,21 +66,21 @@ static DBusMessage *create_dbus_message(int argc, char **argv,
 
         if (!strcmp(argv[n], "--tab"))
         {
-            if (global_options_workspace == -1)
+            if (global_options_workspace == WORKSPACE_UNDEFINED)
             {
                 guint32 ws;
 
                 if (x11support_get_current_desktop(
                         gdk_get_default_root_window(), &ws))
                 {
-                    global_options_workspace = (int) ws;
+                    global_options_workspace = ws;
                 }
                 else
                 {
                     g_warning(_("Unable to read current workspace"));
                 }
             }
-            sprintf(tmp, "--tab=%d", global_options_workspace);
+            sprintf(tmp, "--tab=%u", global_options_workspace);
             arg = tmp;
         }
         else
