@@ -54,7 +54,7 @@ struct MultiTab {
     double scroll_step;
     GtkWidget *close_button;
     GtkWidget *label_box;
-    const char *status_stock;
+    const char *status_icon_name;
     GtkWidget *rename_dialog;
     gboolean postponed_free;
     gboolean old_win_destroyed;
@@ -247,7 +247,7 @@ MultiTab *multi_tab_new(MultiWin * parent, gpointer user_data_template)
     guint pos;
 
     tab->parent = parent;
-    tab->status_stock = NULL;
+    tab->status_icon_name = NULL;
     tab->show_number = TRUE;
     tab->widget = multi_tab_filler(parent, tab, user_data_template,
         &tab->user_data, &tab->active_widget, &tab->adjustment);
@@ -856,7 +856,7 @@ void multi_win_select_tab(MultiWin * win, MultiTab * tab)
 
         if (tab->label)
             multitab_label_cancel_attention(MULTITAB_LABEL(tab->label));
-        multi_tab_set_status_stock(tab, NULL);
+        multi_tab_set_status_icon_name(tab, NULL);
         win->user_data_template = tab->user_data;
         gtk_notebook_set_current_page(GTK_NOTEBOOK(win->notebook),
             multi_tab_get_page_num(tab));
@@ -1306,8 +1306,8 @@ static void multi_win_name_tab_action(MultiWin * win)
     GtkWidget *dialog_w = gtk_dialog_new_with_buttons(_("Name Tab"),
             GTK_WINDOW(win->gtkwin),
             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-            GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+            _("_Cancel"), GTK_RESPONSE_CANCEL,
+            _("_Apply"), GTK_RESPONSE_APPLY,
             NULL);
     GtkDialog *dialog = GTK_DIALOG(dialog_w);
     GtkWidget *name_w = gtk_entry_new();
@@ -1352,13 +1352,13 @@ static void multi_win_set_window_title_action(MultiWin * win)
     GtkWidget *dialog_w = gtk_dialog_new_with_buttons(_("Set Window Title"),
             GTK_WINDOW(win->gtkwin),
             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-            GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+            _("_Cancel"), GTK_RESPONSE_CANCEL,
+            _("_Apply"), GTK_RESPONSE_APPLY,
             NULL);
     GtkDialog *dialog = GTK_DIALOG(dialog_w);
     GtkWidget *title_w = gtk_entry_new();
     GtkEntry *title_e = GTK_ENTRY(title_w);
-    GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO,
+    GtkWidget *img = gtk_image_new_from_icon_name("dialog-information",
             GTK_ICON_SIZE_DIALOG);
     GtkWidget *tip_label = gtk_label_new(_("The title string may include '%s' "
             "which is substituted with the title set by the child command "
@@ -1379,8 +1379,10 @@ static void multi_win_set_window_title_action(MultiWin * win)
     box_compat_packv(content_area, title_w, FALSE, 8);
     box_compat_packh(hbox, img, FALSE, 8);
     gtk_label_set_line_wrap(GTK_LABEL(tip_label), TRUE);
-    box_compat_packh(hbox, tip_label, TRUE, 8);
-    box_compat_packv(content_area, hbox, TRUE, 8);
+    gtk_label_set_width_chars(GTK_LABEL(tip_label), 30);
+    gtk_label_set_max_width_chars(GTK_LABEL(tip_label), 50);
+    box_compat_packh(hbox, tip_label, FALSE, 8);
+    box_compat_packv(content_area, hbox, FALSE, 8);
     gtk_entry_set_activates_default(title_e, TRUE);
     gtk_entry_set_text(title_e, win->title_template ? win->title_template : "");
     gtk_widget_show_all(dialog_w);
@@ -1848,6 +1850,20 @@ static gboolean multi_win_delete_event_cb(GtkWidget *widget, GdkEvent *event,
     return TRUE;
 }
 
+#if NEED_TRANSPARENCY_FIX
+static gboolean
+multi_win_draw(GtkWidget *widget, cairo_t *cr, void *handle)
+{
+    GtkStyleContext *context = gtk_widget_get_style_context(widget);
+    int width = gtk_widget_get_allocated_width(widget);
+    int height = gtk_widget_get_allocated_height(widget);
+    (void) handle;
+    gtk_render_background(context, cr, 0, 0, width, height);
+    gtk_render_frame(context, cr, 0, 0, width, height);
+    return FALSE;
+}
+#endif
+
 MultiWin *multi_win_new_blank(const char *display_name, Options *shortcuts,
         int zoom_index,
         gboolean disable_menu_shortcuts, gboolean disable_tab_shortcuts,
@@ -1925,6 +1941,11 @@ MultiWin *multi_win_new_blank(const char *display_name, Options *shortcuts,
             G_CALLBACK(multi_win_map_event_handler), win);
 #endif
 
+#if NEED_TRANSPARENCY_FIX
+    g_signal_connect(win->gtkwin, "draw", G_CALLBACK(multi_win_draw), win);
+    gtk_widget_set_app_paintable(win->gtkwin, TRUE);
+#endif
+
 #if GTK_CHECK_VERSION(3, 0, 0)
     win->vbox = gtk_grid_new();
     gtk_orientable_set_orientation(GTK_ORIENTABLE(win->vbox),
@@ -2009,7 +2030,7 @@ MultiWin *multi_win_new_blank(const char *display_name, Options *shortcuts,
         multi_win_set_show_tabs_menu_items(win, FALSE);
         multi_win_hide_tabs(win);
     }
-    win->add_tab_button = multitab_close_button_new(GTK_STOCK_ADD);
+    win->add_tab_button = multitab_close_button_new("list-add");
     g_signal_connect_swapped(win->add_tab_button, "clicked",
             G_CALLBACK(multi_win_new_tab_action), win);
     gtk_notebook_set_action_widget(notebook, win->add_tab_button, GTK_PACK_END);
@@ -2208,7 +2229,7 @@ void multi_tab_add_close_button(MultiTab *tab)
         return;
 
     win = tab->parent;
-    tab->close_button = multitab_close_button_new(tab->status_stock);
+    tab->close_button = multitab_close_button_new(tab->status_icon_name);
     gtk_box_pack_start(GTK_BOX(tab->label_box), tab->close_button,
             FALSE, FALSE, 0);
     g_signal_connect(tab->close_button, "clicked",
@@ -2236,18 +2257,18 @@ void multi_tab_remove_close_button(MultiTab *tab)
     }
 }
 
-void multi_tab_set_status_stock(MultiTab *tab, const char *stock)
+void multi_tab_set_status_icon_name(MultiTab *tab, const char *name)
 {
-    if (!strcmp(tab->status_stock ? tab->status_stock : GTK_STOCK_CLOSE,
-            stock ? stock : GTK_STOCK_CLOSE))
+    if (!strcmp(tab->status_icon_name ? tab->status_icon_name : "window-close",
+            name ? name : "window-close"))
     {
         return;
     }
-    tab->status_stock = stock;
+    tab->status_icon_name = name;
     if (tab->close_button)
     {
         multitab_close_button_set_image(
-                MULTITAB_CLOSE_BUTTON(tab->close_button), stock);
+                MULTITAB_CLOSE_BUTTON(tab->close_button), name);
     }
 }
 
@@ -2456,27 +2477,23 @@ Options *multi_win_get_shortcut_scheme(MultiWin * win)
     return win->shortcuts;
 }
 
-void multi_win_set_shortcut_scheme(MultiWin *win, Options *shortcuts,
-        gboolean reapply)
+void multi_win_set_shortcut_scheme(MultiWin *win, Options *shortcuts)
 {
-    if (win->shortcuts != shortcuts || reapply)
+    if (win->shortcuts && win->shortcuts != shortcuts)
     {
-        if (win->shortcuts && win->shortcuts != shortcuts)
-        {
-            UNREF_LOG(shortcuts_unref(win->shortcuts));
-        }
-        if (win->shortcuts != shortcuts)
-        {
-            options_ref(shortcuts);
-            win->shortcuts = shortcuts;
-        }
-        if (win->menu_bar)
-            menutree_apply_shortcuts(win->menu_bar, shortcuts);
-        if (win->popup_menu)
-            menutree_apply_shortcuts(win->popup_menu, shortcuts);
-        if (win->short_popup)
-            menutree_apply_shortcuts(win->short_popup, shortcuts);
+        UNREF_LOG(shortcuts_unref(win->shortcuts));
     }
+    if (win->shortcuts != shortcuts)
+    {
+        options_ref(shortcuts);
+        win->shortcuts = shortcuts;
+    }
+    if (win->menu_bar)
+        menutree_apply_shortcuts(win->menu_bar, shortcuts);
+    if (win->popup_menu)
+        menutree_apply_shortcuts(win->popup_menu, shortcuts);
+    if (win->short_popup)
+        menutree_apply_shortcuts(win->short_popup, shortcuts);
 }
 
 GtkAccelGroup *multi_win_get_accel_group(MultiWin * win)
