@@ -203,7 +203,7 @@ void multi_tab_cancel_attention(MultiTab *tab);
 
 void multi_tab_add_close_button(MultiTab *tab);
 void multi_tab_remove_close_button(MultiTab *tab);
-void multi_tab_set_status_stock(MultiTab *tab, const char *stock);
+void multi_tab_set_status_icon_name(MultiTab *tab, const char *name);
 
 void multi_tab_set_middle_click_tab_action(MultiTab *tab, int action);
 
@@ -352,8 +352,7 @@ MenuTree *multi_win_get_short_popup_menu(MultiWin * win);
 
 Options *multi_win_get_shortcut_scheme(MultiWin * win);
 
-/* reapply is for forcing an update of the current scheme */
-void multi_win_set_shortcut_scheme(MultiWin * win, Options *, gboolean reapply);
+void multi_win_set_shortcut_scheme(MultiWin * win, Options *);
 
 GtkAccelGroup *multi_win_get_accel_group(MultiWin * win);
 
