@@ -32,9 +32,7 @@
 #include "options.h"
 #include "profilegui.h"
 
-#if !VTE_BACKGROUND_DEPRECATED
 #define MANAGE_PREVIEW
-#endif
 
 struct _ProfileGUI {
     CappletData capp;
@@ -48,6 +46,7 @@ struct _ProfileGUI {
         guint term : 1;
         guint browser : 1;
         guint mailer : 1;
+        guint ssh : 1;
         guint filer : 1;
         guint dir_filer : 1;
         guint command : 1;
@@ -106,6 +105,7 @@ void profilegui_check_entries_for_changes(ProfileGUI * pg)
     PG_UPDATE_IF(term)
     PG_UPDATE_IF(browser)
     PG_UPDATE_IF(mailer)
+    PG_UPDATE_IF(ssh)
     PG_UPDATE_IF(filer)
     PG_UPDATE_IF(dir_filer)
     PG_UPDATE_IF(command)
@@ -113,7 +113,6 @@ void profilegui_check_entries_for_changes(ProfileGUI * pg)
     PG_UPDATE_IF(win_title)
 }
 
-#if !VTE_BACKGROUND_DEPRECATED
 static void profilegui_set_bgimg_shading(ProfileGUI *pg, gboolean sensitive)
 {
     gtk_widget_set_sensitive(profilegui_widget(pg,
@@ -140,7 +139,6 @@ static void profilegui_set_background_shading(ProfileGUI *pg)
     profilegui_set_transparency_shading(pg, !gtk_toggle_button_get_active(
             GTK_TOGGLE_BUTTON(profilegui_widget(pg, "background_type0"))));
 }
-#endif
 
 static void profilegui_set_command_shading(ProfileGUI *pg)
 {
@@ -183,6 +181,7 @@ void on_editable_changed(GtkEditable * editable, ProfileGUI *pg)
     else PG_IF_CHANGED(term);
     else PG_IF_CHANGED(browser);
     else PG_IF_CHANGED(mailer);
+    else PG_IF_CHANGED(ssh);
     else PG_IF_CHANGED(dir_filer);
     else PG_IF_CHANGED(filer);
     else PG_IF_CHANGED(command);
@@ -274,14 +273,9 @@ void on_profile_notebook_switch_page(GtkNotebook * notebook, GtkWidget *page,
  */
 void on_bgtype_toggled(GtkToggleButton *button, ProfileGUI *pg)
 {
-#if VTE_BACKGROUND_DEPRECATED
-    (void) button;
-    (void) pg;
-#else
     if (gtk_toggle_button_get_active(button))
         profilegui_set_background_shading(pg);
     on_radio_toggled(button, &pg->capp);
-#endif
 }
 
 void on_command_toggled(GtkToggleButton *button, ProfileGUI *pg)
@@ -358,7 +352,6 @@ static void on_update_preview(GtkFileChooser *chooser, ProfileGUI *pg)
 }
 #endif
 
-#if !VTE_BACKGROUND_DEPRECATED
 static void profilegui_setup_file_chooser(ProfileGUI *pg)
 {
     GtkFileChooser *chooser =
@@ -415,16 +408,10 @@ static char *get_bgimg_filename(ProfileGUI *pg, GtkFileChooser *chooser)
     capplet_set_string(pg->capp.options, "background_img", new_filename);
     return new_filename;
 }
-#endif
 
 void on_bgimg_chosen(GtkFileChooser *chooser, ProfileGUI *pg)
 {
-#if VTE_BACKGROUND_DEPRECATED
-    (void) chooser;
-    (void) pg;
-#else
     g_free(get_bgimg_filename(pg, chooser));
-#endif
 }
 
 #define DEFAULT_BACKSPACE_BINDING 0
@@ -456,7 +443,6 @@ void on_edit_colour_scheme_clicked(GtkButton *button, ProfileGUI *pg)
     colourgui_open(name, gtk_widget_get_screen(combo));
 }
 
-#if !VTE_BACKGROUND_DEPRECATED
 static char *pg_get_dragged_in_filename(const char *text, gulong length)
 {
     char *first_file = first_file = strstr(text, "\r\n");
@@ -492,7 +478,6 @@ static gboolean bgimg_drag_data_received(GtkWidget *widget,
     g_free(filename);
     return result;
 }
-#endif
 
 static void exit_action_changed(GtkComboBox *combo, ProfileGUI *pg)
 {
@@ -742,6 +727,8 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_set_radio(&pg->capp, "browser_spawn_type", 0);
     capplet_set_text_entry(&pg->capp, "mailer", NULL);
     capplet_set_radio(&pg->capp, "mailer_spawn_type", 0);
+    capplet_set_text_entry(&pg->capp, "ssh", NULL);
+    capplet_set_radio(&pg->capp, "ssh_spawn_type", 2);
     capplet_set_text_entry(&pg->capp, "filer", NULL);
     capplet_set_radio(&pg->capp, "filer_spawn_type", 0);
     capplet_set_text_entry(&pg->capp, "dir_filer", NULL);
@@ -752,7 +739,6 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_set_spin_button(&pg->capp, "height", 24);
     on_cell_size_toggled(GTK_TOGGLE_BUTTON(profilegui_widget(pg, "cell_size")),
             pg);
-#if !VTE_BACKGROUND_DEPRECATED
     capplet_set_radio(&pg->capp, "background_type", 0);
     profilegui_set_background_shading(pg);
     capplet_set_float_range(&pg->capp, "saturation", 1.0);
@@ -760,7 +746,6 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     val = options_lookup_string_with_default(profile, "background_img", "");
     profilegui_fill_in_file_chooser(pg, val);
     g_free(val);
-#endif
     capplet_set_radio(&pg->capp, "scrollbar_pos", 1);
     capplet_set_spin_button(&pg->capp, "scrollback_lines", 1000);
     capplet_set_boolean_toggle(&pg->capp, "scroll_on_output", FALSE);
@@ -819,9 +804,7 @@ static void profilegui_setup_list_store(ProfileGUI *pg)
     static char const *labels[] = {
             N_("Appearance"), N_("General"), N_("Command"),
             N_("Net URIs"), N_("File URIs"),
-#if !VTE_BACKGROUND_DEPRECATED
             N_("Background"),
-#endif
             N_("Scrolling"), N_("Keyboard"), N_("Tabs")
     };
     GtkTreeIter iter;
@@ -916,12 +899,10 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
 
     g_hash_table_insert(profilegui_being_edited, g_strdup(profile_name), pg);
 
-#if !VTE_BACKGROUND_DEPRECATED
     profilegui_setup_file_chooser(pg);
     pg->bgimg_drd = drag_receive_setup_dest_widget(
             profilegui_widget(pg, "bgimg_drag_target_vbox"),
             bgimg_drag_data_received, NULL, pg);
-#endif
     profilegui_fill_in_dialog(pg);
     profilegui_connect_handlers(pg);
 
@@ -957,9 +938,7 @@ void profilegui_delete(ProfileGUI * pg)
     UNREF_LOG(g_object_unref(pg->capp.builder));
     dynamic_options_unref(dynopts, pg->profile_name);
     g_free(pg->profile_name);
-#if !VTE_BACKGROUND_DEPRECATED
     drag_receive_data_delete(pg->bgimg_drd);
-#endif
     g_free(pg);
     capplet_dec_windows();
     configlet_unlock_profiles();
